@@ -2,9 +2,9 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window;
-$App::ClusterSSH::Window::VERSION = '4.13.2_01'; # TRIAL
+$App::ClusterSSH::Window::VERSION = '4.13.2_02'; # TRIAL
 
-$App::ClusterSSH::Window::VERSION = '4.13.201';# ABSTRACT: App::ClusterSSH::Window - Base obejct for different types of window module
+$App::ClusterSSH::Window::VERSION = '4.13.202';# ABSTRACT: App::ClusterSSH::Window - Base obejct for different types of window module
 
 =head1 DESCRIPTION
 
@@ -28,6 +28,10 @@ use base qw/ App::ClusterSSH::Base /;
 sub import {
     my ($class) = @_;
 
+    # If we are building or in test here, just exit
+    # as travis build servers will not have Tk installed
+    return if $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING};
+
     # Find what windows module we should be using and just overlay it into
     # this object
     my $package_name = __PACKAGE__ . '::Tk';
